@@ -1,6 +1,7 @@
 #ifndef MATRIX_H
 #define MATRIX_H
 
+namespace FortranLinalg{
 
 //Simple Matrix storage to abstract row and columnwise ordering
 template <typename TPrecision>
@@ -14,4 +15,6 @@ class Matrix{
     virtual void deallocate() = 0;
 };
 
+}
+
 #endif
